@ECHO OFF
REM WoW UI Backup -- Compresses WoW Interface, WTF, and Cache folders using WinRAR and stores in two locations.
REM Made by Kenneth P.  (Infraded)
REM Email: Infraded@gmail.com

REM --------------------------- CONFIG --------------------------
REM Edit the 'set' values after the REM lines here for your specific folders and options.
REM	WRDrive = WinRar directory drive	eg. C:
REM	WoWDrive = WoW directory drive		eg. C:
REM	WRPath = WinRar path after drive	eg. Programs\WinRar
REM	WoWPath = WoW path after drive		eg. Games\World of Warcraft
REM	WoWEXE = The EXE you want to launch	eg. WoW.exe    or 
REM	Primary backup is inside WoW folder	eg. WowDrive\WoWPath\UI Backup
REM	SBackupDrive = Secondary backup drive	eg. D:
REM	SBackupPath = Secondary backup path	eg. Stuff\WoW UI Backup
REM	LaunchWoW = Launch WoW after backup?	eg. Yes
REM	InfoLines = Add details to step output	eg. No
REM	Debug = Outputs debug info to file	eg. No
REM  *** PLEASE DO NOT USE LEADING OR TRAILING SLASHES ***

set WRDrive=C:
set WoWDrive=C:
set WRPath=Program Files\WinRAR
set WoWPath=Program Files\World of Warcraft
set WoWEXE=WoW.exe
set SBackupDrive=F:
set SBackupPath=WoW UI Backup
set LaunchWoW=No
set InfoLines=Yes
set Debug=No

REM ------------------------- END CONFIG -------------------------

IF %Debug%==Yes (ECHO [                   ] -- ---------------START------------------>>WoW_UI_DEBUG.txt)

REM Set debug timer name
set dtime=%date:~4,2%-%date:~7,2%-%date:~10,4% %time:~0,8%
IF %Debug%==Yes (ECHO [%dtime%] -- Setup debug time>>WoW_UI_DEBUG.txt)

REM Checking for WinRAR and/or command line version and prompt for download if not present.
IF EXIST "%WRDrive%\%WRPath%\rar.exe" (GOTO RYES) ELSE (GOTO WRNO)

:WRNO
IF %Debug%==Yes (ECHO [%dtime%] -- WRAR not found in default location>>WoW_UI_DEBUG.txt)
ECHO This program requires WinRAR to run.
START http://www.rarlabs.com/download.htm
IF %Debug%==Yes (ECHO [%dtime%] -- Prompted to download WRAR>>WoW_UI_DEBUG.txt)
pause
IF EXIST "%WRDrive%\%WRPath%\rar.exe" (GOTO RYES) ELSE (exit)

:RYES
IF %Debug%==Yes (ECHO [%dtime%] -- Found rar.exe in correct location>>WoW_UI_DEBUG.txt)
ECHO Backing up WoW UI.
IF %InfoLines%==Yes (ECHO Creating folder name)

REM Create folder name variable for current date
set fname=%date:~4,2%-%date:~7,2%-%date:~10,4%
IF %Debug%==Yes (ECHO [%dtime%] -- Setup destination folder name by date/time>>WoW_UI_DEBUG.txt)

cls
ECHO Backing up WoW UI..
IF %InfoLines%==Yes (ECHO Creating temp. and destination directories)

REM Create temp directories
md "%systemdrive%\wow_temp\Interface"
IF %Debug%==Yes (ECHO [%dtime%] -- Created temp Interface folder>>WoW_UI_DEBUG.txt)
md "%systemdrive%\wow_temp\WTF"
IF %Debug%==Yes (ECHO [%dtime%] -- Created temp WTF folder>>WoW_UI_DEBUG.txt)
md "%systemdrive%\wow_temp\Cache"
IF %Debug%==Yes (ECHO [%dtime%] -- Created temp Cache folder>>WoW_UI_DEBUG.txt)

REM Create destination directories - change if needed
IF NOT EXIST "%WoWDrive%\%WoWPath%\UI Backup\%fname%" (md "%WoWDrive%\%WoWPath%\UI Backup\%fname%")
IF %Debug%==Yes (ECHO [%dtime%] -- Setup primary backup path>>WoW_UI_DEBUG.txt)
IF NOT EXIST "%SBackupDrive%\%SBackupPath%\%fname%" (md "%SBackupDrive%\%SBackupPath%\%fname%")
IF %Debug%==Yes (ECHO [%dtime%] -- Setup secondary backup path>>WoW_UI_DEBUG.txt)

cls
ECHO Backing up WoW UI...
REM Copy files to temp directory
IF %InfoLines%==Yes (ECHO Copying UI files -Interface- to temp location)
xcopy "%WoWDrive%\%WoWPath%\Interface\*" "%systemdrive%\wow_temp\Interface" /E /Q
IF %Debug%==Yes (ECHO [%dtime%] -- Copied Interface to temp>>WoW_UI_DEBUG.txt)
cls
ECHO Backing up WoW UI...
IF %InfoLines%==Yes (ECHO Copying UI files -WTF- to temp location)
xcopy "%WoWDrive%\%WoWPath%\WTF\*" "%systemdrive%\wow_temp\WTF" /E /Q
IF %Debug%==Yes (ECHO [%dtime%] -- Copied WTF to temp>>WoW_UI_DEBUG.txt)
cls
ECHO Backing up WoW UI...
IF %InfoLines%==Yes (ECHO Copying UI files -Cache- to temp location)
xcopy "%WoWDrive%\%WoWPath%\Cache\*" "%systemdrive%\wow_temp\Cache" /E /Q
IF %Debug%==Yes (ECHO [%dtime%] -- Copied Cache to temp>>WoW_UI_DEBUG.txt)

cls
ECHO Backing up WoW UI....
IF %InfoLines%==Yes (ECHO Compressing UI Files)

REM RAR files to .rar with date and time in filename
REM Adjust m# (0-5) for compression strength...0 is none, 5 is high
IF %Debug%==Yes (ECHO [%dtime%] -- Begin Compression>>WoW_UI_DEBUG.txt)
"%WRDrive%\%WRPath%\rar" a -ep1 -r -m3 -inul -x*.rar -ag+MM-DD-YYYY--HH-MM-SS "%systemdrive%\wow_temp\ UI" "%systemdrive%\wow_temp\"
IF %Debug%==Yes (ECHO [%dtime%] -- End Compression>>WoW_UI_DEBUG.txt)

cls
ECHO Backing up WoW UI.....
IF %InfoLines%==Yes (ECHO Copying backup to primary location)

REM Copy compressed backup to primary location - change if needed
xcopy "%systemdrive%\wow_temp\*.rar" "%WoWDrive%\%WoWPath%\UI Backup\%fname%\" /Q
IF %Debug%==Yes (ECHO [%dtime%] -- Copied rar to primary location>>WoW_UI_DEBUG.txt)

cls
ECHO Backing up WoW UI......
IF %InfoLines%==Yes (ECHO Copying backup to secondary location)

REM Copy compressed backup to secondary location - change if needed - if not needed, add REM to the front of the 2 lines below
xcopy "%systemdrive%\wow_temp\*.rar" "%SBackupDrive%\%SBackupPath%\%fname%\" /Q
IF %Debug%==Yes (ECHO [%dtime%] -- Copied rar to secondary location>>WoW_UI_DEBUG.txt)

cls
ECHO Backing up WoW UI.......
IF %InfoLines%==Yes (ECHO Cleaning up temp files)

REM Delete temp files
rd /S /Q "%systemdrive%\wow_temp"
IF %Debug%==Yes (ECHO [%dtime%] -- Deleted temp files>>WoW_UI_DEBUG.txt)

cls
ECHO Backing up WoW UI........Done! Launching WoW...

REM Causes a small delay to be sure all drive operations are complete
PING 0.0.0.0 -n 1 -w 1500 >NUL

cls
ECHO Backing up WoW UI........Done! Launching WoW...

IF %Debug%==Yes (ECHO [%dtime%] -- Finished with backup>>WoW_UI_DEBUG.txt)

REM Launches WoW if LaunchWoW variable is set to Yes
IF %LaunchWoW%==Yes ("%WoWDrive%\%WoWPath%\%WoWEXE%")

IF %Debug%==Yes (ECHO [%dtime%] -- ---------------END-------------------->>WoW_UI_DEBUG.txt)